@@ -1,4 +1,9 @@
-// Copyright (c) Samuel Gratzl
+/**
+ * @upsetjs/jupyter_widget
+ * https://github.com/upsetjs/upsetjs_jupyter_widget
+ *
+ * Copyright (c) 2020 Samuel Gratzl <sam@sgratzl.com>
+ */
 
 import { DOMWidgetModel, DOMWidgetView, ISerializers } from '@jupyter-widgets/base';
 
@@ -8,7 +13,7 @@ import {
   ISetCombinations,
   ISetLike,
   isSetQuery,
-  renderUpSet,
+  render,
   UpSetProps,
   UpSetQuery,
   boxplotAddon,
@@ -103,7 +108,10 @@ export class UpSetView extends DOMWidgetView {
       if (propName === 'fontSizes') {
         const converted: any = {};
         Object.keys(v).forEach((key: string) => {
-          converted[toCamelCase(key)] = (v as any)![key];
+          const vi = (v as any)![key];
+          if (vi != null) {
+            converted[toCamelCase(key)] = typeof vi === 'number' ? `${vi}px` : String(vi);
+          }
         });
         v = converted;
       }
@@ -211,6 +219,8 @@ export class UpSetView extends DOMWidgetView {
       props.onClick = this.changeSelection;
     } else if (this.model.get('mode') === 'hover') {
       props.onHover = this.changeSelection;
+    } else if (this.model.get('mode') === 'contextMenu') {
+      props.onContextMenu = this.changeSelection;
     }
   }
 
@@ -227,12 +237,12 @@ export class UpSetView extends DOMWidgetView {
         const bb2 = this.el.getBoundingClientRect();
         p.width = bb2.width || 600;
         p.height = bb2.height || 400;
-        renderUpSet(this.el, p);
+        render(this.el, p);
       });
       return;
     }
     p.width = bb.width;
     p.height = bb.height;
-    renderUpSet(this.el, p);
+    render(this.el, p);
   }
 }
