@@ -1,10 +1,14 @@
-# coding: utf-8
-# Copyright (c) Samuel Gratzl.
+# coding: utf- 8
+# @upsetjs/jupyter_widget
+# https://github.com/upsetjs/upsetjs_jupyter_widget
+#
+# Copyright (c) 2020 Samuel Gratzl <sam@sgratzl.com>
+
 """
 UpSet.js Jupyter Widget
 """
 
-from .upset import UpSetWidget
+from .widget import UpSetJSWidget
 from ._model import (
     UpSetBaseSet,
     UpSetQuery,
