@@ -1,3 +1,9 @@
+# coding: utf- 8
+# @upsetjs/jupyter_widget
+# https://github.com/upsetjs/upsetjs_jupyter_widget
+#
+# Copyright (c) 2020 Samuel Gratzl <sam@sgratzl.com>
+
 """
 model definitions for UpSet
 """
@@ -14,6 +20,7 @@ class UpSetSetType(Enum):
 
     SET = ("set",)
     INTERSECTION = "intersection"
+    DISTINCT_INTERSECTION = "distinctIntersection"
     UNION = "union"
     COMPOSITE = "composite"
 
@@ -22,6 +29,8 @@ class UpSetSetType(Enum):
             return "set"
         if self == UpSetSetType.INTERSECTION:
             return "intersection"
+        if self == UpSetSetType.DISTINCT_INTERSECTION:
+            return "distinctIntersection"
         if self == UpSetSetType.UNION:
             return "union"
         return "composite"
@@ -76,7 +85,7 @@ class UpSetSet(UpSetBaseSet[T]):
 
 class UpSetSetCombination(UpSetBaseSet[T]):
     """
-    a set combination within UpSet like an intersection
+    a set combination within UpSet.js like an intersection
     """
 
     sets: t.FrozenSet[UpSetSet[T]]
@@ -120,6 +129,20 @@ class UpSetSetIntersection(UpSetSetCombination[T]):
         super().__init__(UpSetSetType.INTERSECTION, name, elems, sets)
 
 
+class UpSetSetDistinctIntersection(UpSetSetCombination[T]):
+    """
+    a distinct set intersection representation in UpSet
+    """
+
+    def __init__(
+        self,
+        name: str = "",
+        elems: t.Optional[t.FrozenSet[T]] = None,
+        sets: t.Optional[t.FrozenSet[UpSetSet[T]]] = None,
+    ):
+        super().__init__(UpSetSetType.DISTINCT_INTERSECTION, name, elems, sets)
+
+
 class UpSetSetUnion(UpSetSetCombination[T]):
     """
     a set union representation in UpSet
@@ -183,3 +206,37 @@ class UpSetQuery(t.Generic[T]):
                 f"UpSetSetQuery(name={self.name}, color={self.color}, set={self.set})"
             )
         return f"UpSetSetQuery(name={self.name}, color={self.color}, elems={set(self.elems)})"
+
+
+class UpSetFontSizes:
+    """
+    helper structure for specifying font sizes
+    """
+
+    chart_label: t.Union[None, str, int] = None
+    axis_tick: t.Union[None, str, int] = None
+    set_label: t.Union[None, str, int] = None
+    bar_label: t.Union[None, str, int] = None
+    export_label: t.Union[None, str, int] = None
+    legend: t.Union[None, str, int] = None
+    title: t.Union[None, str, int] = None
+    description: t.Union[None, str, int] = None
+
+    def __init__(self, **kwargs):
+        super().__init__()
+        self.__dict__.update(kwargs)
+
+    def __copy__(self):
+        return UpSetFontSizes(**self.__dict__)
+
+    def copy(self):
+        """
+        returns a copy / clone of this instance
+        """
+        return UpSetFontSizes(**self.__dict__)
+
+    def to_json(self):
+        """
+        converts this instance to a regular dictionary for transfering
+        """
+        return self.__dict__
